@@ -27,11 +27,22 @@ setClass(Class = "gergm",
            console_output = "character",
            print_output = "logical",
            is_correlation_network = "logical",
-           undirected_network = "logical",
+           directed_network = "logical",
            simulation_only = "logical",
            thresholds = "numeric",
            BZ = "matrix",
-           BZstdev = "numeric"
+           BZstdev = "numeric",
+           transformation_type = "character",
+           downweight_statistics_together = "logical",
+           hyperparameter_optimization = "logical",
+           target_accept_rate = "numeric",
+           proposal_variance = "numeric",
+           estimation_method = "character",
+           number_of_simulations = "numeric",
+           thin = "numeric",
+           burnin = "numeric",
+           MPLE_gain_factor = "numeric",
+           simulated_statistics_for_GOF = "data.frame"
          ),
          validity = function(object) {
            if (!"matrix" %in% class(object@network) & is.null(object@network)
